pub enum EsModuleFlag {
Always,
Never,
IfDefaultProp,
}Expand description
This configuration determines how the bundler should handle the synthetic __esModule property in the CJS and IIFE format.
It is rollup-capable, and the rollup default is IfDefaultProp.
You may find rollup explanation here.
Whether to add a
__esModule: trueproperty when generating exports for non-ES formats. This property signifies that the exported value is the namespace of an ES module and that the default export of this module corresponds to the.defaultproperty of the exported object.From rollupjs.org
Variants
Always
Always generate Object.defineProperty(exports, "__esModule", { value: true });
in the CJS and IIFE format. It is similar to other bundlers’ behavior.
Never
Never generate the synthetic __esModule property in the CJS and IIFE format.
IfDefaultProp
Generate the synthetic __esModule property in the CJS and IIFE format only
if the module has a default export.
It will only add the property when using named exports mode and there also is a default export. The subtle difference is that if there is no default export, consumers of the CommonJS version of your library will get all named exports as default export instead of an error or
undefined. We chose to make this the default value as the__esModuleproperty is not a standard followed by any JavaScript runtime and leads to many interop issues, so we want to limit its use to the cases where it is really needed.From rollupjs.org
For example, rolldown will define the __esModule property in the following entry code:
export default function() {}
export const a = 1; // For this module, rolldown will automatically regard it as the `named` export mode.And rolldown won’t generate the __esModule property in the following entry code:
export const a = 1;Trait Implementations
Sourceimpl Clone for EsModuleFlag
impl Clone for EsModuleFlag
Sourcefn clone(&self) -> EsModuleFlag
fn clone(&self) -> EsModuleFlag
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Copy for EsModuleFlag
Sourceimpl Debug for EsModuleFlag
impl Debug for EsModuleFlag
Sourceimpl Default for EsModuleFlag
impl Default for EsModuleFlag
Sourcefn default() -> EsModuleFlag
fn default() -> EsModuleFlag
Sourceimpl From<String> for EsModuleFlag
impl From<String> for EsModuleFlag
Sourcefn from(value: String) -> EsModuleFlag
fn from(value: String) -> EsModuleFlag
Sourceimpl From<bool> for EsModuleFlag
impl From<bool> for EsModuleFlag
Sourcefn from(value: bool) -> EsModuleFlag
fn from(value: bool) -> EsModuleFlag