pub struct Bundle<Fs: FileSystem + Clone + 'static = OsFileSystem> { /* private fields */ }Implementations
Sourceimpl<Fs: FileSystem + Clone + 'static> Bundle<Fs>
impl<Fs: FileSystem + Clone + 'static> Bundle<Fs>
Sourcepub async fn write(self) -> BuildResult<BundleOutput>
pub async fn write(self) -> BuildResult<BundleOutput>
This method intentionally get the ownership of self to show that the method cannot be called multiple times.
Sourcepub async fn generate(self) -> BuildResult<BundleOutput>
pub async fn generate(self) -> BuildResult<BundleOutput>
This method intentionally get the ownership of self to show that the method cannot be called multiple times.
Sourcepub async fn scan(self) -> BuildResult<()>
pub async fn scan(self) -> BuildResult<()>
This method intentionally get the ownership of self to show that the method cannot be called multiple times.
pub async fn scan_modules( &mut self, scan_mode: ScanMode<ArcStr>, ) -> BuildResult<NormalizedScanStageOutput>
pub fn options(&self) -> &SharedNormalizedBundlerOptions
pub fn get_watch_files(&self) -> &Arc<FxDashSet<ArcStr>> ⓘ
pub fn context(&self) -> BundleHandle
pub async fn bundle_write( &mut self, scan_stage_output: NormalizedScanStageOutput, ) -> BuildResult<BundleOutput>
pub async fn bundle_generate( &mut self, scan_stage_output: NormalizedScanStageOutput, ) -> BuildResult<BundleOutput>