RuntimeHelper

Struct RuntimeHelper 

pub struct RuntimeHelper(/* private fields */);

Implementations

Source

impl RuntimeHelper

Source

impl RuntimeHelper

pub const fn empty() -> RuntimeHelper

Get a flags value with all bits unset.

pub const fn all() -> RuntimeHelper

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<RuntimeHelper>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> RuntimeHelper

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> RuntimeHelper

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<RuntimeHelper>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: RuntimeHelper) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: RuntimeHelper) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: RuntimeHelper)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: RuntimeHelper)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: RuntimeHelper)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: RuntimeHelper, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: RuntimeHelper) -> RuntimeHelper

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: RuntimeHelper) -> RuntimeHelper

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: RuntimeHelper) -> RuntimeHelper

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: RuntimeHelper) -> RuntimeHelper

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> RuntimeHelper

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl RuntimeHelper

pub const fn iter(&self) -> Iter<RuntimeHelper>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<RuntimeHelper>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl RuntimeHelper

pub fn bit_index(&self) -> usize

Use with caution

Only used when there is only one bit is set in the RuntimeHelper. The function is used to get the index of the bit that is set.