pub struct RuntimeHelper(/* private fields */);Implementations
Sourceimpl RuntimeHelper
impl RuntimeHelper
pub const Create: RuntimeHelper
pub const DefProp: RuntimeHelper
pub const Name: RuntimeHelper
pub const GetOwnPropDesc: RuntimeHelper
pub const GetOwnPropNames: RuntimeHelper
pub const GetProtoOf: RuntimeHelper
pub const HasOwnProp: RuntimeHelper
pub const Esm: RuntimeHelper
pub const EsmMin: RuntimeHelper
pub const CommonJs: RuntimeHelper
pub const CommonJsMin: RuntimeHelper
pub const ExportAll: RuntimeHelper
pub const CopyProps: RuntimeHelper
pub const ReExport: RuntimeHelper
pub const ToEsm: RuntimeHelper
pub const ToCommonJs: RuntimeHelper
pub const ToBinaryNode: RuntimeHelper
pub const ToBinary: RuntimeHelper
pub const Require: RuntimeHelper
Sourceimpl RuntimeHelper
impl RuntimeHelper
Sourcepub const fn empty() -> RuntimeHelper
pub const fn empty() -> RuntimeHelper
Get a flags value with all bits unset.
Sourcepub const fn all() -> RuntimeHelper
pub const fn all() -> RuntimeHelper
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<RuntimeHelper>
pub const fn from_bits(bits: u32) -> Option<RuntimeHelper>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> RuntimeHelper
pub const fn from_bits_truncate(bits: u32) -> RuntimeHelper
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> RuntimeHelper
pub const fn from_bits_retain(bits: u32) -> RuntimeHelper
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RuntimeHelper>
pub fn from_name(name: &str) -> Option<RuntimeHelper>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RuntimeHelper) -> bool
pub const fn intersects(&self, other: RuntimeHelper) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RuntimeHelper) -> bool
pub const fn contains(&self, other: RuntimeHelper) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RuntimeHelper)
pub fn insert(&mut self, other: RuntimeHelper)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RuntimeHelper)
pub fn remove(&mut self, other: RuntimeHelper)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RuntimeHelper)
pub fn toggle(&mut self, other: RuntimeHelper)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RuntimeHelper, value: bool)
pub fn set(&mut self, other: RuntimeHelper, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: RuntimeHelper) -> RuntimeHelper
pub const fn intersection(self, other: RuntimeHelper) -> RuntimeHelper
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: RuntimeHelper) -> RuntimeHelper
pub const fn union(self, other: RuntimeHelper) -> RuntimeHelper
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: RuntimeHelper) -> RuntimeHelper
pub const fn difference(self, other: RuntimeHelper) -> RuntimeHelper
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: RuntimeHelper) -> RuntimeHelper
pub const fn symmetric_difference(self, other: RuntimeHelper) -> RuntimeHelper
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RuntimeHelper
pub const fn complement(self) -> RuntimeHelper
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RuntimeHelper
impl RuntimeHelper
Sourcepub const fn iter(&self) -> Iter<RuntimeHelper>
pub const fn iter(&self) -> Iter<RuntimeHelper>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RuntimeHelper>
pub const fn iter_names(&self) -> IterNames<RuntimeHelper>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.